@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2015 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Forms\Navigation;
 
@@ -14,7 +14,7 @@ use Icinga\Exception\NotFoundError;
 use Icinga\Exception\ProgrammingError;
 use Icinga\Forms\ConfigForm;
 use Icinga\User;
-use Icinga\Util\String;
+use Icinga\Util\StringHelper;
 use Icinga\Web\Form;
 
 /**
@@ -426,11 +426,6 @@ class NavigationConfigForm extends ConfigForm
         }
 
         $itemConfig->merge($data);
-        foreach ($itemConfig->toArray() as $k => $v) {
-            if ($v === null) {
-                unset($itemConfig->$k);
-            }
-        }
 
         if ($shared) {
             // Share all descendant children
@@ -761,17 +756,6 @@ class NavigationConfigForm extends ConfigForm
         return $valid;
     }
 
-    /**
-     * {@inheritdoc}
-     */
-    public function getValues($suppressArrayNotation = false)
-    {
-        $values = parent::getValues();
-        $values = array_merge($values, $values['item_form']);
-        unset($values['item_form']);
-        return $values;
-    }
-
     /**
      * {@inheritdoc}
      */
@@ -828,7 +812,7 @@ class NavigationConfigForm extends ConfigForm
      */
     protected function getItemForm($type)
     {
-        $className = String::cname($type, '-') . 'Form';
+        $className = StringHelper::cname($type, '-') . 'Form';
 
         $form = null;
         foreach (Icinga::app()->getModuleManager()->getLoadedModules() as $module) {
