@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2014 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Module\Setup\Utils;
 
@@ -262,6 +262,25 @@ class DbTool
         );
 
         if ($this->config['db'] === 'mysql') {
+            if (isset($this->config['use_ssl']) && $this->config['use_ssl']) {
+                $this->config['driver_options'] = array();
+                # The presence of these keys as empty strings or null cause non-ssl connections to fail
+                if ($this->config['ssl_key']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_KEY] = $this->config['ssl_key'];
+                }
+                if ($this->config['ssl_cert']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_CERT] = $this->config['ssl_cert'];
+                }
+                if ($this->config['ssl_ca']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_CA] = $this->config['ssl_ca'];
+                }
+                if ($this->config['ssl_capath']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_CAPATH] = $this->config['ssl_capath'];
+                }
+                if ($this->config['ssl_cipher']) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_CIPHER] = $this->config['ssl_cipher'];
+                }
+            }
             $this->zendConn = new Zend_Db_Adapter_Pdo_Mysql($config);
         } elseif ($this->config['db'] === 'pgsql') {
             $this->zendConn = new Zend_Db_Adapter_Pdo_Pgsql($config);
@@ -286,11 +305,39 @@ class DbTool
             return;
         }
 
+        $driverOptions = array(
+            PDO::ATTR_TIMEOUT => 1,
+            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION
+        );
+
+        if (
+            $this->config['db'] === 'mysql'
+            && isset($this->config['use_ssl'])
+            && $this->config['use_ssl']
+        ) {
+            # The presence of these keys as empty strings or null cause non-ssl connections to fail
+            if ($this->config['ssl_key']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_KEY] = $this->config['ssl_key'];
+            }
+            if ($this->config['ssl_cert']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_CERT] = $this->config['ssl_cert'];
+            }
+            if ($this->config['ssl_ca']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_CA] = $this->config['ssl_ca'];
+            }
+            if ($this->config['ssl_capath']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_CAPATH] = $this->config['ssl_capath'];
+            }
+            if ($this->config['ssl_cipher']) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_CIPHER] = $this->config['ssl_cipher'];
+            }
+        }
+
         $this->pdoConn = new PDO(
             $this->buildDsn($this->config['db'], $dbname),
             $this->config['username'],
             $this->config['password'],
-            array(PDO::ATTR_TIMEOUT => 1, PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
+            $driverOptions
         );
     }
 
